==> bodhi-cli-0.7.10.tgz: package/lib/controllers/EnvironmentController.js <==
module.exports = function EnvController(project, options){

    var _  = require('../utils.js');


    function create(name, spec){

        project.createEnvironment(name, spec);

        project.save(function(err){
            if(err){
                if(options.verbose) console.log('ERROR. Unable to write the project file');
            } else {
                if(options.verbose) {
                    console.log('Project File Saved' + project.getProjectFile());
                } else {
                    console.log(name);
                }
            }
        })
    }

    function list(){
        var envs = [];

        _.forEach(project.getEnvironments(), function(env, name){
            envs.push(name);
        });

        var defaultEnv = (project.hasDefaultEnv()) ? project.getDefaultEnvironment(): null;

        if(envs.length < 1){
            console.log('No environments available');
        } else {
            var list = envs.sort();
            console.log('Available Environments\n---------');
            _.forEach(list, function(name){
                if(project.getDefaultEnvironment() === name){
                    console.log('* %s', name);
                } else {
                    console.log('  %s', name);
                }

            });
        }
    }


    function rename(from, to, patch){

        if(!project.hasEnvironment(from)){
            console.log("Unknown environment '" + from + "'" );
            return;
        }

        if(project.hasEnvironment(to) && !(options.force)){
            console.log("Connection '" + to + "' already exists" );
            return;
        }

        if(options.verbose) console.log('Renaming Connection ' + from + ' to ' + to);

        project.renameEnvironment(from, to, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved' + project.getProjectFile());
                    } else {
                        console.log(to);
                    }
                }
            });
    }

    function copy(from, to, patch){

        if(!project.hasEnvironment(from)){
            console.log("Unknown environment '" + from + "'" );
            return;
        }

        if(project.hasEnvironment(to) && !(options.force)){
            console.log("Connection '" + to + "' already exists. Use --force to overwrite" );
            return;
        }

        if(options.verbose) console.log('Copying Connection ' + from + ' to ' + to + '...');

        project.copyEnvironment(from, to, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved' + project.getProjectFile());
                    } else {
                        console.log(to);
                    }
                }
            });
    }

    function view(name, attribute){
        if(!project.hasEnvironment(name)){
            console.log("Unknown environment '" + name + "'" );
        } else {
            var env = project.getEnvironment(name);
            if(!attribute){
                console.log(env.toJSON());
            } else {

                var attribute;

                if(attribute === 'location'){
                    attribute = env.createClient().getBaseUri()
                } else {
                    attribute = env.get(attribute.toLowerCase())
                }

                console.log(attribute);
            }
        }
    }

    function update(name, patch){

        if(!project.hasEnvironment(name)){
            console.log("Unknown environment '" + name + "'" );
            return;
        }

        if(options.verbose) console.log('Updating Connection ', name + " ...");

        project.patchEnvironment(name, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved ' + project.getProjectFile());
                    } else {
                        console.log(name);
                    }
                }
            });

    }

    function remove(name){

        if(!project.hasEnvironment(name)){
            console.log("Unknown environment '" + name + "'" );
            return;
        }

        if(options.verbose) console.log('Removing the environment ' + name + " ...");

        project.removeEnvironment(name)
        project.save(function(err){
            if(err){
                if(options.verbose) console.log('ERROR. Unable to save the project file');
            } else {
                if(options.verbose) {
                    console.log('Project File Saved ' + project.getProjectFile());
                } else {
                    console.log(name);
                }
            }
        })

    }

    return {
           list        : list
        ,  create      : create
        ,  rename      : rename
        ,  view        : view
        ,  copy        : copy
        ,  update      : update
        ,  remove      : remove
    }

}

==> bodhi-cli-0.9.13.tgz: package/lib/controllers/EnvironmentController.js <==
module.exports = function EnvController(project, options){

    var _  = require('../utils.js');

    function create(name, spec){

        project.createEnvironment(name, spec);

        project.save(function(err){
            if(err){
                if(options.verbose) console.log('ERROR. Unable to write the project file');
            } else {
                if(options.verbose) {
                    console.log('Project File Saved' + project.getProjectFile());
                } else {
                    console.log('created new environment %s', name);
                }
            }
        })
    }

    function list(){
        var envs = [];

        _.forEach(project.getEnvironments(), function(env, name){
            envs.push(name);
        });

        var defaultEnv = (project.hasDefaultEnv()) ? project.getDefaultEnvironment(): null;

        if(envs.length < 1){
            console.log('No environments available');
        } else {
            var list = envs.sort();
            console.log('Available Environments\n---------');
            _.forEach(list, function(name){
                if(project.getDefaultEnvironment() === name){
                    console.log('* %s', name);
                } else {
                    console.log('  %s', name);
                }

            });
        }
    }


    function rename(from, to, patch){

        if(!project.hasEnvironment(from)){
            console.log("Unknown environment '" + from + "'" );
            return;
        }

        if(project.hasEnvironment(to) && !(options.force)){
            console.log("Connection '" + to + "' already exists" );
            return;
        }

        if(options.verbose) console.log('Renaming Connection ' + from + ' to ' + to);

        project.renameEnvironment(from, to, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved' + project.getProjectFile());
                    } else {
                        console.log('environment %s renamed to %s', from, to);
                    }
                }
            });
    }

    function copy(from, to, patch){

        if(!project.hasEnvironment(from)){
            console.log("Unknown environment '" + from + "'" );
            return;
        }

        if(project.hasEnvironment(to) && !(options.force)){
            console.log("Connection '" + to + "' already exists. Use --force to overwrite" );
            return;
        }

        if(options.verbose) console.log('Copying Connection ' + from + ' to ' + to + '...');

        project.copyEnvironment(from, to, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved' + project.getProjectFile());
                    } else {
                        console.log('%s saved as %s', from, to);
                    }
                }
            });
    }

    function view(name, attribute){

        var defaultEnv = (project.hasDefaultEnv()) ? project.getDefaultEnvironment(): null;

        if(!(project.hasEnvironment(name) || defaultEnv)){
            if(name) {
                console.log("Environment '%s' not registered", name);
            } else {
                console.log('Unspecified default environment');
            }
        } else {
            var env = project.getEnvironment(name) || project.getEnvironment(defaultEnv);
            if(!attribute){
                console.log(env.toJSON());
            } else {
                var attribute;
                if(attribute === 'location'){
                    attribute = env.createClient().getBaseUri()
                } else {
                    attribute = env.get(attribute.toLowerCase())
                }
                console.log(env.toJSON());
            }
        }
    }

    function update(name, patch){

        if(!project.hasEnvironment(name)){
            console.log("Unknown environment '" + name + "'" );
            return;
        }

        if(options.verbose) console.log('Updating environment ', name + " ...");

        project.patchEnvironment(name, patch)
            .save(function(err){
                if(err){
                    console.log('ERROR. Unable to write the project file');
                } else {
                    if(options.verbose) {
                        console.log('Project File Saved ' + project.getProjectFile());
                    } else {
                        console.log(name);
                    }
                }
            });

    }

    function remove(name){

        if(!project.hasEnvironment(name)){
            console.log("Unknown environment '" + name + "'" );
            return;
        }

        if(options.verbose) console.log('Removing the environment %s ...', name);

        project.removeEnvironment(name)
        project.save(function(err){
            if(err){
                if(options.verbose) console.log('ERROR. Unable to save the project file');
            } else {
                if(options.verbose) {
                    console.log('Project File Saved ' + project.getProjectFile());
                } else {
                    console.log('removed the environment %s', name);
                }
            }
        })

    }

    return {
           list        : list
        ,  create      : create
        ,  rename      : rename
        ,  view        : view
        ,  copy        : copy
        ,  update      : update
        ,  remove      : remove
    }

}
